import h2o_mlops_client as mlops

# Defines MLOps API URL. The address for the MLOps Gateway component.
# Usually: "https://api.mlops.my.domain"
MLOPS_API_URL = ""

# Defines IDP's token endpoint URL. For deployments using Keycloak as IDP:
# https://mlops.keycloak.domain/auth/realms/[fill-in-realm-name]/protocol/openid-connect/token
TOKEN_ENDPOINT_URL = ""

# Defines user's refresh token.
REFRESH_TOKEN = ""

# Sets client id for authentication.
CLIENT_ID = ""

# Sets client secret for authentication.
CLIENT_SECRET = ""

# Sets project id (Create a project if not exist).
PROJECT_ID = ""

# Sets model name of a registered model.
MODEL_DISPLAY_NAME = ""

# Sets model description for the registered model.
MODEL_DESCRIPTION = ""


# Create the registered model in given project.
def create_registered_model(
    mlops_client: mlops.Client, 
    create_model_request: mlops.StorageCreateRegisteredModelRequest
):
    return mlops_client.storage.registered_model.create_registered_model(create_model_request)


def create_registered_model_request(
    display_name, description, project_id
):
    return mlops.StorageCreateRegisteredModelRequest(
        registered_model=mlops.StorageRegisteredModel(
            display_name=display_name, 
            description=description,
            project_id=project_id
            )
        )


def main():
    # Set up the token provider using an existing refresh token.
    mlops_token_provider = mlops.TokenProvider(
        refresh_token=REFRESH_TOKEN,
        client_id=CLIENT_ID,
        client_secret=CLIENT_SECRET,
        token_endpoint_url=TOKEN_ENDPOINT_URL,
    )

    # Set up the MLOps client.
    mlops_client = mlops.Client(
        gateway_url=MLOPS_API_URL,
        token_provider=mlops_token_provider,
    )

    registered_model_response: mlops.StorageGetRegisteredModelResponse = create_registered_model(
        mlops_client,
            create_registered_model_request(
                display_name=MODEL_DISPLAY_NAME,
                description=MODEL_DESCRIPTION,
                project_id=PROJECT_ID
            )
        )
    print(registered_model_response)


if __name__ == "__main__":
    main()